#!/bin/bash

displayManualMessage() {
	echo -e "\nYou can manually download and install $1 at $2"
}

if [ "$#" -ne 3 ]; then
	echo "usage: installer.sh language-id display-name manual-url"
	exit 1
fi

echo -e "\n\033[1mTo run your code, you need to have $2 installed.\033[0m\n"
read -p "Would you like to download and install $2 now? [y/n]: " -r
if [[ ! $REPLY =~ ^[Yy] ]]; then
	displayManualMessage "$2" "$3"
	exit 1
fi

echo -e "\nRetrieving package information..."
url=$(curl -fs "https://coderunnerapp.com/api.php?action=install&language=$1")
if [[ "$url" = "" ]]; then
	echo "Error: Failed to get URL for package download."
	displayManualMessage "$2" "$3"
	exit 1
fi
file="$HOME/Downloads/${url##*/}"
echo "Downloading package: $url"
echo -e "Saving as: $file\n"

trap "rm $file" SIGHUP SIGKILL

curl -f -L "$url" -o "$file"

if [ $? -ne 0 ]; then
	rm "$file"
	echo -e "\nDownload failed."
	displayManualMessage "$2" "$3"
	exit 1
fi

echo "Launching installer..."
open "$file"